from distutils.core import setup
setup(
  name='challonge-service',
  packages=['challongeservice'],
  version='0.0.1',
  description='Python binding for Challonge v1 API',
  author='Hugo Wainwright',
  author_email='wainwrighthugo@gmail.com',
  url='https://github.com/frugs/challonge-service',
  download_url='https://github.com/frugs/challonge-service/tarball/0.0.1',
  keywords=['challonge'],
  classifiers=[],
)
